#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 HsYAML-aeson
version:              0.2.0.2
visibility:           public
id:                   HsYAML-aeson-0.2.0.2-DQqwzddu8ff40CL7JuePkN
key:                  HsYAML-aeson-0.2.0.2-DQqwzddu8ff40CL7JuePkN
license:              GPL-2.0-or-later
copyright:            2018-2019 Herbert Valerio Riedel
maintainer:           Andreas Abel
author:               Herbert Valerio Riedel
synopsis:             JSON to YAML Adapter
description:
    The [YAML 1.2](https://yaml.org/spec/1.2/spec.html) format provides
    a much richer data-model and feature-set
    than the [JavaScript Object Notation (JSON)](https://tools.ietf.org/html/rfc7159) format.
    However, sometimes it'\''s desirable to ignore the extra capabilities
    and treat YAML as if it was merely a more convenient markup format
    for humans to write JSON data. To this end this module provides a
    compatibility layer atop [HsYAML](https://hackage.haskell.org/package/HsYAML)
    which allows decoding YAML documents in the more limited JSON data-model while also providing
    convenience by reusing [aeson](https://hackage.haskell.org/package/aeson)'\''s
    '\''FromJSON'\'' instances for decoding the YAML data into native Haskell data types.

category:             Text, Codec, Web, JSON, YAML
abi:                  4206cd374736e670b0137856b566051a
exposed:              True
exposed-modules:      Data.YAML.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/HsYAML-aeson-0.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hsyaml-aeson
hs-libraries:         HSHsYAML-aeson-0.2.0.2-DQqwzddu8ff40CL7JuePkN
depends:
    HsYAML-0.2.1.5-E1aHAuuceeF1h5lzAQ1JbY
    aeson-2.2.1.0-4WRExiZ7zbh8CS1DZxw1Qy base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 mtl-2.3.1
    scientific-0.3.8.1-DLJUsVzfkt8S4sgDRE9je text-2.0.2
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE

haddock-interfaces:
    /usr/share/doc/haskell-hsyaml-aeson/html/HsYAML-aeson.haddock

haddock-html:         /usr/share/doc/haskell-hsyaml-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

